@@ -38,8 +38,12 @@ public:
     virtual ~LiveSettings();
 
 private:
-    static void on_changed(GSettings*, gchar*, gpointer);
-    void update_key(const std::string& key);
+    static void on_changed_ccid(GSettings*, gchar*, gpointer);
+    static void on_changed_cal_notification(GSettings*, gchar*, gpointer);
+    static void on_changed_general_notification(GSettings*, gchar*, gpointer);
+    void update_key_ccid(const std::string& key);
+    void update_key_cal_notification(const std::string& key);
+    void update_key_general_notification(const std::string& key);
 
     void update_custom_time_format();
     void update_locations();
@@ -60,8 +64,16 @@ private:
     void update_alarm_duration();
     void update_alarm_haptic();
     void update_snooze_duration();
+    void update_cal_notification_enabled();
+    void update_cal_notification_sounds();
+    void update_cal_notification_vibrations();
+    void update_cal_notification_bubbles();
+    void update_cal_notification_list();
+    void update_vibrate_silent_mode();
 
     GSettings* m_settings;
+    GSettings* m_settings_cal_notification;
+    GSettings* m_settings_general_notification;
 
     // we've got a raw pointer here, so disable copying
     LiveSettings(const LiveSettings&) =delete;
