@@ -1,5 +1,6 @@
 /*
  * Copyright 2014 Canonical Ltd.
+ * Copyright 2021 Robert Tari
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -15,8 +16,13 @@
  *
  * Authors:
  *   Charles Kerr <charles.kerr@canonical.com>
+ *   Robert Tari <robert@tari.in>
  */
 
+#ifndef ALARM_DEFAULT_SOUND
+#define ALARM_DEFAULT_SOUND "dummy"
+#endif
+
 #include <datetime/engine-eds.h>
 #include <datetime/myself.h>
 #include <libical/ical.h>
@@ -35,10 +41,8 @@ namespace ayatana {
 namespace indicator {
 namespace datetime {
 
-static constexpr char const * TAG_ALARM    {"x-canonical-alarm"};
-static constexpr char const * TAG_DISABLED {"x-canonical-disabled"};
-
-static constexpr char const * X_PROP_ACTIVATION_URL {"X-CANONICAL-ACTIVATION-URL"};
+static constexpr char const * TAG_ALARM    {"x-lomiri-alarm"};
+static constexpr char const * TAG_DISABLED {"x-lomiri-disabled"};
 
 /****
 *****
@@ -48,7 +52,7 @@ class EdsEngine::Impl
 {
 public:
 
-    Impl(const std::shared_ptr<Myself> &myself)
+    explicit Impl(const std::shared_ptr<Myself> &myself)
         : m_myself(myself)
     {
         auto cancellable_deleter = [](GCancellable * c) {
@@ -137,9 +141,9 @@ public:
         }
     }
 
-    void disable_ubuntu_alarm(const Appointment& appointment)
+    void disable_alarm(const Appointment& appointment)
     {
-        if (appointment.is_ubuntu_alarm())
+        if (appointment.is_alarm())
         {
             for (auto& kv : m_clients) // find the matching icalcomponent
             {
@@ -473,14 +477,14 @@ private:
         // for each component..
         for (auto l=components; l!=nullptr; l=l->next)
         {
-            bool changed = false;
+            bool bChanged = false;
 
             // for each alarm...
             auto component = E_CAL_COMPONENT(l->data);
             auto auids = e_cal_component_get_alarm_uids(component);
-            for(auto l=auids; l!=nullptr; l=l->next)
+            for(auto lAlarms=auids; lAlarms!=nullptr; lAlarms=lAlarms->next)
             {
-                auto auid = static_cast<const char*>(l->data);
+                auto auid = static_cast<const char*>(lAlarms->data);
                 auto alarm = e_cal_component_get_alarm(component, auid);
                 if (alarm == nullptr)
                     continue;
@@ -490,13 +494,13 @@ private:
                 {
                     e_cal_component_remove_alarm (component, auid);
                     e_cal_component_add_alarm (component, new_alarm);
-                    changed = true;
+                    bChanged = true;
                     g_clear_pointer (&new_alarm, e_cal_component_alarm_free);
                 }
             }
             g_slist_free_full (auids, g_free);
 
-            if (changed)
+            if (bChanged)
             {
                 auto icc = e_cal_component_get_icalcomponent(component); // icc owned by ecc
                 modify_slist = g_slist_prepend(modify_slist, icc);
@@ -913,7 +917,20 @@ private:
         if (identifier == nullptr)
             g_warning("Unrecognized TZID: '%s'", tzid);
         else
-            return g_time_zone_new(identifier);
+        {
+            #if GLIB_CHECK_VERSION(2, 68, 0)
+            auto pZone = g_time_zone_new_identifier(identifier);
+
+            if (pZone == NULL)
+            {
+                pZone = g_time_zone_new_utc();
+            }
+            #else
+            auto pZone = g_time_zone_new(identifier);
+            #endif
+
+            return pZone;
+        }
 
         return nullptr;
     }
@@ -1047,26 +1064,14 @@ private:
         }
         g_clear_pointer (&eccdt_tmp, e_cal_component_datetime_free);
 
-        // get appointment.activation_url from x-props
-        auto icc = e_cal_component_get_icalcomponent(component); // icc owned by component
-        auto icalprop = i_cal_component_get_first_property(icc, I_CAL_X_PROPERTY);
-        while (icalprop != nullptr) {
-            const char * x_name = i_cal_property_get_x_name(icalprop);
-            if ((x_name != nullptr) && !g_ascii_strcasecmp(x_name, X_PROP_ACTIVATION_URL)) {
-                const char * url = i_cal_property_get_value_as_string(icalprop);
-                if ((url != nullptr) && baseline.activation_url.empty())
-                    baseline.activation_url = url;
-            }
-            icalprop = i_cal_component_get_next_property(icc, I_CAL_X_PROPERTY);
-        }
-
         // get appointment.type
         baseline.type = Appointment::EVENT;
+        auto icc = e_cal_component_get_icalcomponent(component); // icc owned by component
         auto categ_list = e_cal_component_get_categories_list (component);
         for (GSList * l=categ_list; l!=nullptr; l=l->next) {
             auto tag = static_cast<const char*>(l->data);
             if (!g_strcmp0(tag, TAG_ALARM))
-                baseline.type = Appointment::UBUNTU_ALARM;
+                baseline.type = Appointment::ALARM;
         }
         g_slist_free_full(categ_list, g_free);
 
@@ -1126,9 +1131,9 @@ private:
                 alarm.text = get_alarm_text(a);
 
             if (alarm.audio_url.empty())
-                alarm.audio_url = get_alarm_sound_url(a,  (baseline.is_ubuntu_alarm() ?
-                                                         "file://" ALARM_DEFAULT_SOUND :
-                                                         "file://" CALENDAR_DEFAULT_SOUND));
+            {
+                alarm.audio_url = get_alarm_sound_url(a,  (baseline.is_alarm() ? "file://" ALARM_DEFAULT_SOUND : "file://" CALENDAR_DEFAULT_SOUND));
+            }
 
             if (!alarm.time.is_set())
                 alarm.time = trigger_time;
@@ -1210,7 +1215,7 @@ private:
                 }
             }
 
-            g_clear_pointer(&icc, icalcomponent_free);
+            g_clear_pointer(&icc, i_cal_component_free);
         }
     }
 
@@ -1265,9 +1270,9 @@ void EdsEngine::get_appointments(const DateTime& begin,
     p->get_appointments(begin, end, tz, func);
 }
 
-void EdsEngine::disable_ubuntu_alarm(const Appointment& appointment)
+void EdsEngine::disable_alarm(const Appointment& appointment)
 {
-    p->disable_ubuntu_alarm(appointment);
+    p->disable_alarm(appointment);
 }
 
 /***
