@@ -1,5 +1,6 @@
 /*
  * Copyright 2013 Canonical Ltd.
+ * Copyright 2021 Robert Tari
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -15,18 +16,23 @@
  *
  * Authors:
  *   Charles Kerr <charles.kerr@canonical.com>
+ *   Robert Tari <robert@tari.in>
  */
 
 #include <datetime/menu.h>
-
 #include <datetime/formatter.h>
 #include <datetime/state.h>
-
 #include <glib/gi18n.h>
 #include <gio/gio.h>
-
+#include <algorithm>
+#include <iterator>
 #include <vector>
 
+extern "C"
+{
+    #include <ayatana/common/utils.h>
+}
+
 namespace ayatana {
 namespace indicator {
 namespace datetime {
@@ -56,12 +62,86 @@ GMenuModel* Menu::menu_model()
     return G_MENU_MODEL(m_menu);
 }
 
+/**
+ * To avoid a giant menu on the PC, and to avoid pushing lower menu items
+ * off-screen on the phone, the menu should show the
+ * next five calendar events, if any.
+ *
+ * The list might include multiple occurrences of the same event (bug 1515821).
+ */
+std::vector<Appointment>
+Menu::get_display_appointments(const std::vector<Appointment>& appointments_in,
+                               const DateTime& now,
+                               unsigned int max_items)
+{
+    std::vector<Appointment> appointments;
+    std::copy_if(appointments_in.begin(),
+                 appointments_in.end(),
+                 std::back_inserter(appointments),
+                 [now](const Appointment& a){return a.end >= now;});
+
+    if (appointments.size() > max_items)
+    {
+        const auto next_minute = now.add_full(0,0,0,0,1,-now.seconds());
+        const auto start_of_day = now.start_of_day();
+        const auto end_of_day = now.end_of_day();
+
+        /*
+         * If there are more than five, the events shown should be, in order of priority:
+         * 1. any events that start or end (bug 1329048) after the current minute today;
+         * 2. any full-day events that span all of today (bug 1302004);
+         * 3. any events that start or end tomorrow;
+         * 4. any events that start or end the day after tomorrow; and so on.
+         */
+        auto compare = [next_minute, start_of_day, end_of_day](
+            const Appointment& a,
+            const Appointment& b)
+        {
+            const bool a_later_today = (a.begin >= next_minute) || (a.end <= end_of_day);
+            const bool b_later_today = (b.begin >= next_minute) || (b.end <= end_of_day);
+            if (a_later_today != b_later_today)
+                return a_later_today;
+
+            const bool a_full_day_today = (a.begin <= start_of_day) && (end_of_day <= a.end);
+            const bool b_full_day_today = (b.begin <= start_of_day) && (end_of_day <= b.end);
+            if (a_full_day_today != b_full_day_today)
+                return a_full_day_today;
+
+            if (a.begin != b.begin)
+                return a.begin < b.begin;
+            if (b.end != b.end)
+                return a.end < b.end;
+
+            return false;
+        };
+        std::sort(appointments.begin(), appointments.end(), compare);
+        appointments.resize(max_items);
+    }
+
+    /*
+     * However, the display order should be the reverse: full-day events
+     * first (since they start first), part-day events afterward in
+     * chronological order. If multiple events have exactly the same start+end
+     * time, they should be sorted alphabetically.
+     */
+    auto compare = [](const Appointment& a, const Appointment& b)
+    {
+        if (a.begin != b.begin)
+            return a.begin < b.begin;
+
+        if (a.end != b.end)
+            return a.end < b.end;
+
+        return a.summary < b.summary;
+    };
+    std::sort(appointments.begin(), appointments.end(), compare);
+    return appointments;
+}
 
 /****
 *****
 ****/
 
-
 #define ALARM_ICON_NAME "alarm-clock"
 #define CALENDAR_ICON_NAME "calendar"
 
@@ -78,6 +158,12 @@ protected:
         m_actions(actions),
         m_formatter(formatter)
     {
+        if (m_pSettings == NULL && profile_in != Phone && profile_in != PhoneGreeter)
+        {
+            m_pSettings = g_settings_new("org.ayatana.common");
+            g_signal_connect(m_pSettings, "changed::max-menu-text-length", G_CALLBACK(on_string_length_changed), this);
+        }
+
         // initialize the menu
         create_gmenu();
         for (int i=0; i<NUM_SECTIONS; i++)
@@ -123,10 +209,16 @@ protected:
         g_clear_object(&m_menu);
         g_clear_pointer(&m_serialized_alarm_icon, g_variant_unref);
         g_clear_pointer(&m_serialized_calendar_icon, g_variant_unref);
+        g_clear_object(&m_pSettings);
     }
 
     virtual GVariant* create_header_state() =0;
 
+    static void on_string_length_changed(GSettings *pSettings, gchar *sKey, gpointer pSelf)
+    {
+        static_cast<MenuImpl*>(pSelf)->update_section(Appointments);
+    }
+
     void update_header()
     {
         auto action_group = m_actions->action_group();
@@ -137,25 +229,19 @@ protected:
 
     void update_upcoming()
     {
-        // The usual case is on desktop (and /only/ case on phone)
-        // is that we're looking at the current date and want to see
-        // "the next five calendar events, if any."
-        //
-        // However on the Desktop when the user clicks onto a different
-        // calendar date, show the next five calendar events starting
-        // from the beginning of that clicked day.
-        DateTime begin;
+        // The usual case is to show events germane to the current time.
+        // However when the user clicks onto a different calendar date,
+        // we pick events starting from the beginning of that clicked day.
         const auto now = m_state->clock->localtime();
         const auto calendar_day = m_state->calendar_month->month().get();
-        if ((profile() == Desktop) && !DateTime::is_same_day(now, calendar_day))
-            begin = calendar_day.start_of_day();
-        else
-            begin = now.start_of_minute();
+        const auto begin = DateTime::is_same_day(now, calendar_day)
+            ? now.start_of_minute()
+            : calendar_day.start_of_day();
 
-        std::vector<Appointment> upcoming;
-        for(const auto& a : m_state->calendar_upcoming->appointments().get())
-            if (begin <= a.begin)
-                upcoming.push_back(a);
+        auto upcoming = get_display_appointments(
+            m_state->calendar_upcoming->appointments().get(),
+            begin
+        );
 
         if (m_upcoming != upcoming)
         {
@@ -308,11 +394,12 @@ private:
             auto fmt = m_formatter->relative_format(begin, end);
             auto unix_time = g_date_time_to_unix(begin);
 
+            ayatana_common_utils_ellipsize((char*)appt.summary.c_str());
             auto menu_item = g_menu_item_new (appt.summary.c_str(), nullptr);
             g_menu_item_set_attribute (menu_item, "x-ayatana-time", "x", unix_time);
             g_menu_item_set_attribute (menu_item, "x-ayatana-time-format", "s", fmt.c_str());
 
-            if (appt.is_ubuntu_alarm())
+            if (appt.is_alarm())
             {
                 g_menu_item_set_attribute (menu_item, "x-ayatana-type", "s", "org.ayatana.indicator.alarm");
                 g_menu_item_set_attribute_value(menu_item, G_MENU_ATTRIBUTE_ICON, get_serialized_alarm_icon());
@@ -325,9 +412,12 @@ private:
             if (!appt.color.empty())
                 g_menu_item_set_attribute (menu_item, "x-ayatana-color", "s", appt.color.c_str());
 
-            if (action_name != nullptr)
+            if (action_name != nullptr) {
                 g_menu_item_set_action_and_target_value (menu_item, action_name,
-                                                         g_variant_new_string (appt.uid.c_str()));
+                                                         g_variant_new ("(sx)",
+                                                                        appt.uid.c_str(),
+                                                                        unix_time));
+            }
 
             g_menu_append_item (menu, menu_item);
             g_object_unref (menu_item);
@@ -437,6 +527,7 @@ private:
 //private:
     GVariant * m_serialized_alarm_icon = nullptr;
     GVariant * m_serialized_calendar_icon = nullptr;
+    GSettings *m_pSettings = NULL;
 
 }; // class MenuImpl
 
@@ -459,7 +550,7 @@ protected:
         update_header();
     }
 
-    GVariant* create_header_state()
+    GVariant* create_header_state() override
     {
         const auto title = _("Date and Time");
         auto label = g_variant_new_string(m_formatter->header.get().c_str());
@@ -502,19 +593,25 @@ protected:
         update_header();
     }
 
-    GVariant* create_header_state()
+    GVariant* create_header_state() override
     {
         // are there alarms?
-        bool has_ubuntu_alarms = false;
+        bool has_alarms = false;
         for(const auto& appointment : m_upcoming)
-            if((has_ubuntu_alarms = appointment.is_ubuntu_alarm()))
+        {
+            has_alarms = appointment.is_alarm();
+
+            if (has_alarms)
+            {
                 break;
+            }
+        }
 
         GVariantBuilder b;
         g_variant_builder_init(&b, G_VARIANT_TYPE_VARDICT);
         g_variant_builder_add(&b, "{sv}", "title", g_variant_new_string (_("Time and Date")));
         g_variant_builder_add(&b, "{sv}", "visible", g_variant_new_boolean (TRUE));
-        if (has_ubuntu_alarms)
+        if (has_alarms)
         {
             auto label = m_formatter->header.get();
             auto a11y = g_strdup_printf(_("%s (has alarms)"), label.c_str());
